@@ -55,8 +55,8 @@ public:
     GpgME::Protocol protocol() const;
 
 private:
-    void doStart() Q_DECL_OVERRIDE;
-    void doCancel() Q_DECL_OVERRIDE;
+    void doStart() override;
+    void doCancel() override;
 
 private:
     class Private;
