@@ -46,7 +46,7 @@ class QDir;
 
 namespace Kleo
 {
-
+class Output;
 class Input
 {
 public:
@@ -63,6 +63,7 @@ public:
     static std::shared_ptr<Input> createFromPipeDevice(assuan_fd_t fd, const QString &label);
     static std::shared_ptr<Input> createFromFile(const QString &filename, bool dummy = false);
     static std::shared_ptr<Input> createFromFile(const std::shared_ptr<QFile> &file);
+    static std::shared_ptr<Input> createFromOutput(const std::shared_ptr<Output> &output); // implemented in output.cpp
     static std::shared_ptr<Input> createFromProcessStdOut(const QString &command);
     static std::shared_ptr<Input> createFromProcessStdOut(const QString &command, const QStringList &args);
     static std::shared_ptr<Input> createFromProcessStdOut(const QString &command, const QStringList &args, const QDir &workingDirectory);
